// Replication code for: Populism and the scales of statehood
// Authors: Daniel Kübler, Michael A. Strebel, Frank Marcinkowski
// Contact information: michael.strebel@unibe.ch
// Software version: Stata/IC 15.1
// File version: 2023-10-04


// 1. Load data
use DemGovCit_Survey.dta, clear

// 2. Recoding
rename *, lower

gen weight=faktv3 if country!=1 // survey weights variable
replace weight=faktv3_ch if country==1

	// 2.1 Dependent variable: populist attitudes
{
factor q14_a-q14_h, ml  // factor analysis for populist attitudes: 3 factors */
rotate, promax oblique

alpha q14_a q14_b /* anti_elite: cronbach's a=.82 */
alpha q14_c q14_d /* pop_sov: cronbach's a=.77 */
alpha q14_e-q14_h /* people_cent: cronbach's a=.82 */
alpha q14_a-q14_h /* populism: cronbach's a=.8 */

foreach var of varlist q14_a-q14_h { // rescale all items from 0 to 4 instead 1 to 5
replace `var'=`var'-1
}

gen people_cent=(q14_e+q14_f+q14_g+q14_h)/4
label variable people_cent "People-centrism"
gen pop_sov=(q14_c+q14_d)/2
label variable pop_sov "Popular sovereignty"
gen anti_elite=(q14_a+q14_b)/2
label variable anti_elite "Anti-elitism"

gen populism=((q14_e+q14_f+q14_g+q14_h)*(q14_c+q14_d)*(q14_a+q14_b))^(1/3) /* geometric mean (cubic root) of the sum of the three components */
label variable populism "Populism (overall)"

sum populism // normalize populism variable between 0 and 4
replace populism=(4-0)*(((populism-r(min))/r(max)-r(min)))+0

gen populist=. // dummy variable for populist vs non-populist citizens
replace populist=0 if people_cent!=. & pop_sov!=. & anti_elite!=.
replace populist=1 if people_cent>=3 & people_cent!=. & pop_sov>=3 & pop_sov!=. & anti_elite>=3 & anti_elite!=.
label variable populist "Populist citizen (=1)"
}

	// 2.2 Independent variable: scalar orientations
{
gen level_loc=q32_b // attachment levels to different scales
label variable level_loc "Level of local attachment"
gen level_nat=q32_d
label variable level_nat "Level of national attachment"
gen level_glob=q32_e
label variable level_glob "Level of European attachment"

gen loc_att_rel=q32_b-q32_d // local orientation
label variable loc_att_rel "Local scalar orientation"

gen eu_att_rel=q32_e-q32_d // European orientation
label variable eu_att_rel "European scalar orientation"

}

	// 2.3 Controls
{
gen immigration_neg=q15_d // anti-immigrant sentiment
label variable immigration_neg "Anti-immigration sentiments"

gen left_right=q18 // left-right self-placement
label variable left_right "Left-right self-placement"

gen party_id=0 // party identification
replace party_id=1 if q19_1==1 // party identifiers, non-populist
replace party_id=2 if q19_2_sc_f==9 | strpos(q19_2_sc_andere_f, "Front de") /// left-wing populists
| q19_2_mc1_f==9 | q19_2_mc2_f==9 | q19_2_mc3_f==9
replace party_id=2 if q19_2_sc_d==6 | q19_2_mc1_d==6 | q19_2_mc2_d==6 | q19_2_mc3_d==6
replace party_id=3 if q19_2_sc_f==5 | strpos(q19_2_sc_andere_f, "Debout") | strpos(q19_2_sc_andere_f, "debout") /// right-wing populists
| q19_2_mc1_f==5 | q19_2_mc2_f==5 | q19_2_mc3_f==5
replace party_id=3 if q19_2_sc_d==11 | q19_2_mc1_d==11 | q19_2_mc2_d==11 | q19_2_mc3_d==11 ///
| q19_2_sc_d==7 | q19_2_mc1_d==7 | q19_2_mc2_d==7 | q19_2_mc3_d==7
replace party_id=3 if q19_2_sc_ch==4 | strpos(q19_2_sc_andere_ch, "Parteilos") ///
| q19_2_mc1_ch==4 | q19_2_mc2_ch==4 | q19_2_mc3_ch==4 | q19_2_mc4_ch==4 | q19_2_mc5_ch==4 ///
| q19_2_sc_ch==22 | q19_2_mc1_ch==22 | q19_2_mc2_ch==22 | q19_2_mc3_ch==22 | q19_2_mc4_ch==22 | q19_2_mc5_ch==22 ///
| q19_2_sc_ch==19 | q19_2_mc1_ch==19 | q19_2_mc2_ch==19 | q19_2_mc3_ch==19 | q19_2_mc4_ch==19 | q19_2_mc5_ch==19 ///
| q19_2_sc_ch==18 | q19_2_mc1_ch==18 | q19_2_mc2_ch==18 | q19_2_mc3_ch==18 | q19_2_mc4_ch==18 | q19_2_mc5_ch==18
replace party_id=3 if q19_2_sc_uk==4 | q19_2_mc1_uk==4 | q19_2_mc2_uk==4 ///
| q19_2_sc_uk==5 | q19_2_mc1_uk==5 | q19_2_mc2_uk==5
label def pid 0 "None" 1 "Other" 2 "Left-wing populist" 3 "Right-wing populist"
label val party_id pid
label variable party_id "Party identification"

gen party_reg=0 // regional parties
replace party_reg=1 if q19_2_sc_ch==19 | q19_2_mc1_ch==19 | q19_2_mc2_ch==19 | q19_2_mc3_ch==19 | q19_2_mc4_ch==19 | q19_2_mc5_ch==19 ///
| q19_2_sc_ch==22 | q19_2_mc1_ch==22 | q19_2_mc2_ch==22 | q19_2_mc3_ch==22 | q19_2_mc4_ch==22 | q19_2_mc5_ch==22
replace party_reg=1 if q19_2_sc_d==2 | q19_2_mc1_d==2 | q19_2_mc2_d==2 | q19_2_mc3_d==2
replace party_reg=1 if q19_2_sc_uk==6 | q19_2_mc1_uk==6 | q19_2_mc2_uk==6 ///
| q19_2_sc_uk==8 | q19_2_mc1_uk==8 | q19_2_mc2_uk==8
labe def preg 0 "No" 1 "Yes"
label val party_reg preg
label variable party_reg "Regionalist party supporter"

gen age=2015-q27 // age categories
gen age_group=0 if age<=25
replace age_group=1 if age>25 & age<=35
replace age_group=2 if age>35 & age<=45
replace age_group=3 if age>45 & age<=45
replace age_group=4 if age>55 & age<=65
replace age_group=5 if age>65 & age!=.
label def age 0 "<26" 1 "26-35" 2 "36-45" 3 "46-55" 4 "56-65" 5 ">65"
label val age_group age
label variable age_group "Age"

gen gender=. // gender
replace gender=q26 if q26!=3
label def gend 1 "Female" 2 "Gender (male=1)"
label val gender gend
label variable gender "Gender (male=1)"

gen education_tertiary=0 if q33_isced<5 // education
replace education_tertiary=1 if q33_isced>4 & q33_isced!=.
label def educ 0 "No tertiary education" 1 "Tertiary education (=1)"
label val education_tertiary educ
label variable education_tertiary "Tertiary education (=1)"

label def cty 1 "Switzerland" 2 "Germany" 3 "France" 4 "United Kingdom" // country
label val country cty
}

// 3. Bivariate assessment
{
pwcorr loc_att_rel anti_elite people_cent pop_sov populism, sig // Table 1: populism and local orientation

pwcorr eu_att_rel anti_elite people_cent pop_sov populism, sig // Table 1: populism and European orientation

preserve  // Figure 1: The scalar orientations of "populists"
{
collapse (mean) loc_att_rel eu_att_rel level_loc level_nat level_glob /// 
(sd) loc_att_rel_sd=loc_att_rel eu_att_rel_sd=eu_att_rel level_loc_sd=level_loc level_nat_sd=level_nat level_glob_sd=level_glob /// 
(count) loc_att_rel_n=loc_att_rel eu_att_rel_n=eu_att_rel level_loc_n=level_loc level_nat_n=level_nat level_glob_n=level_glob, by(populist)

gen loc_att_rel_ub = loc_att_rel + invttail(loc_att_rel_n-1,0.025)*(loc_att_rel_sd / sqrt(loc_att_rel_n)) // local scalar orientation
gen loc_att_rel_lb = loc_att_rel - invttail(loc_att_rel_n-1,0.025)*(loc_att_rel_sd / sqrt(loc_att_rel_n))

graph twoway (bar loc_att_rel populist, barwidth(0.7) lcolor(black)) /// 
(rcap loc_att_rel_ub loc_att_rel_lb populist, lcolor(black)), /// 
ylabel(-2(0.5)0.5, grid glcolor(gs14) glwidth(vthin)) yline(0, lpattern(shortdash)) ///
ytitle("Local scalar orientation") scheme(s1mono) graphregion(lcolor(white)) ///
legend(off) yscale(range(-2.4(0.5)0.5)) ///
xlabel(0 "No populist" 1 "Populist") xtitle("") saving(loc_att_rel, replace)

gen eu_att_rel_ub = eu_att_rel + invttail(eu_att_rel_n-1,0.025)*(eu_att_rel_sd / sqrt(eu_att_rel_n)) // European scalar orientation
gen eu_att_rel_lb = eu_att_rel - invttail(eu_att_rel_n-1,0.025)*(eu_att_rel_sd / sqrt(eu_att_rel_n))

graph twoway (bar eu_att_rel populist, barwidth(0.7) lcolor(black)) /// 
(rcap eu_att_rel_ub eu_att_rel_lb populist, lcolor(black)), /// 
ylabel(-2(0.5)0.5, grid glcolor(gs14) glwidth(vthin)) yline(0, lpattern(shortdash)) ///
ytitle("European scalar orientation") scheme(s1mono) graphregion(lcolor(white)) ///
legend(off) yscale(range(-2.4(0.5)0.5)) ///
xlabel(0 "No populist" 1 "Populist") xtitle("") saving(eu_att_rel, replace)

gen level_loc_ub = level_loc + invttail(level_loc_n-1,0.025)*(level_loc_sd / sqrt(level_loc_n)) // local attachment
gen level_loc_lb = level_loc - invttail(level_loc_n-1,0.025)*(level_loc_sd / sqrt(level_loc_n))

graph twoway (bar level_loc populist, barwidth(0.7) lcolor(black)) /// 
(rcap level_loc_ub level_loc_lb populist, lcolor(black)), /// 
ylabel(0(2.5)10, grid glcolor(gs14) glwidth(vthin)) ///
ytitle("Local attachment") scheme(s1mono) graphregion(lcolor(white)) ///
legend(off) yscale(range(0(2.5)10)) ///
xlabel(0 "No populist" 1 "Populist") xtitle("") saving(level_loc, replace)

gen level_nat_ub = level_nat + invttail(level_nat_n-1,0.025)*(level_nat_sd / sqrt(level_nat_n)) // national attachment
gen level_nat_lb = level_nat - invttail(level_nat_n-1,0.025)*(level_nat_sd / sqrt(level_nat_n))

graph twoway (bar level_nat populist, barwidth(0.7) lcolor(black)) /// 
(rcap level_nat_ub level_nat_lb populist, lcolor(black)), /// 
ylabel(0(2.5)10, grid glcolor(gs14) glwidth(vthin)) ///
ytitle("National attachment") scheme(s1mono) graphregion(lcolor(white)) ///
legend(off) yscale(range(0(2.5)10)) ///
xlabel(0 "No populist" 1 "Populist") xtitle("") saving(level_nat, replace)

gen level_glob_ub = level_glob + invttail(level_glob_n-1,0.025)*(level_glob_sd / sqrt(level_glob_n)) // European attachment
gen level_glob_lb = level_glob - invttail(level_glob_n-1,0.025)*(level_glob_sd / sqrt(level_glob_n))

graph twoway (bar level_glob populist, barwidth(0.7) lcolor(black)) /// 
(rcap level_glob_ub level_glob_lb populist, lcolor(black)), /// 
ylabel(0(2.5)10, grid glcolor(gs14) glwidth(vthin)) ///
ytitle("European attachment") scheme(s1mono) graphregion(lcolor(white)) ///
legend(off) yscale(range(0(2.5)10)) ///
xlabel(0 "No populist" 1 "Populist") xtitle("") saving(level_glob, replace)

restore
}
graph combine level_loc.gph level_nat.gph level_glob.gph, /// 
scheme(s1mono) graphregion(lcolor(white)) iscale(0.7) rows(1) 
graph export Figure_1a.png, width(2000) replace

graph combine loc_att_rel.gph eu_att_rel.gph, /// 
scheme(s1mono) graphregion(lcolor(white)) iscale(0.7) rows(1)
graph export Figure_1b.png, width(2000) replace


erase loc_att_rel.gph
erase eu_att_rel.gph
erase level_loc.gph 
erase level_nat.gph 
erase level_glob.gph

preserve // Figure A1: Populist attitudes and party identification
{
collapse (mean) populism pop_sov people_cent anti_elite /// 
(sd) populism_sd=populism pop_sov_sd=pop_sov people_cent_sd=people_cent anti_elite_sd=anti_elite /// 
(count) populism_n=populism pop_sov_n=pop_sov people_cent_n=people_cent anti_elite_n=anti_elite, by(party_id)

gen populism_ub = populism + invttail(populism_n-1,0.025)*(populism_sd / sqrt(populism_n)) // populism
gen populism_lb = populism - invttail(populism_n-1,0.025)*(populism_sd / sqrt(populism_n))

graph twoway (bar populism party_id, barwidth(0.7) lcolor(black)) /// 
(rcap populism_ub populism_lb party_id, lcolor(black)), /// 
ylabel(, grid glcolor(gs14) glwidth(vthin)) ///
ytitle("Populism (overall)") scheme(s1mono) graphregion(lcolor(white)) ///
legend(off) ///
xlabel(0 "None" 1 "Other" 2 `""Left-wing" "populist""' 3 `""Right-wing" "populist""') xtitle("") saving(populism_pid, replace)

gen pop_sov_ub = pop_sov + invttail(pop_sov_n-1,0.025)*(pop_sov_sd / sqrt(pop_sov_n)) // popular sovereignty
gen pop_sov_lb = pop_sov - invttail(pop_sov_n-1,0.025)*(pop_sov_sd / sqrt(pop_sov_n))

graph twoway (bar pop_sov party_id, barwidth(0.7) lcolor(black)) /// 
(rcap pop_sov_ub pop_sov_lb party_id, lcolor(black)), /// 
ylabel(, grid glcolor(gs14) glwidth(vthin)) ///
ytitle("Popular sovereignty") scheme(s1mono) graphregion(lcolor(white)) ///
legend(off) xscale(range(0(1)3)) ///
xlabel(0 "None" 1 "Other" 2 `""Left-wing" "populist""' 3 `""Right-wing" "populist""') xtitle("") saving(pop_sov_pid, replace)

gen people_cent_ub = people_cent + invttail(people_cent_n-1,0.025)*(people_cent_sd / sqrt(people_cent_n)) // people-centrism
gen people_cent_lb = people_cent - invttail(people_cent_n-1,0.025)*(people_cent_sd / sqrt(people_cent_n))

graph twoway (bar people_cent party_id, barwidth(0.7) lcolor(black)) /// 
(rcap people_cent_ub people_cent_lb party_id, lcolor(black)), /// 
ylabel(, grid glcolor(gs14) glwidth(vthin)) ///
ytitle("People-centrism") scheme(s1mono) graphregion(lcolor(white)) ///
legend(off) xscale(range(0(1)3)) ///
xlabel(0 "None" 1 "Other" 2 `""Left-wing" "populist""' 3 `""Right-wing" "populist""') xtitle("") saving(people_cent_pid, replace)

gen anti_elite_ub = anti_elite + invttail(anti_elite_n-1,0.025)*(anti_elite_sd / sqrt(anti_elite_n)) // anti-elitism
gen anti_elite_lb = anti_elite - invttail(anti_elite_n-1,0.025)*(anti_elite_sd / sqrt(anti_elite_n))

graph twoway (bar anti_elite party_id, barwidth(0.7) lcolor(black)) /// 
(rcap anti_elite_ub anti_elite_lb party_id, lcolor(black)), /// 
ylabel(, grid glcolor(gs14) glwidth(vthin)) ///
ytitle("Anti-elitism") scheme(s1mono) graphregion(lcolor(white)) ///
legend(off) xscale(range(0(1)3)) ///
xlabel(0 "None" 1 "Other" 2 `""Left-wing" "populist""' 3 `""Right-wing" "populist""') xtitle("") saving(anti_elite_pid, replace)

restore
}
graph combine populism_pid.gph pop_sov_pid.gph people_cent_pid.gph anti_elite_pid.gph, /// 
scheme(s1mono) graphregion(lcolor(white)) iscale(0.7) 
graph export Figure_A1.png, width(2000) replace

erase populism_pid.gph 
erase pop_sov_pid.gph 
erase people_cent_pid.gph 
erase anti_elite_pid.gph



}

// 4. Main analysis

	// 4.1 Direct effects of local and European scalar orientation on populist attitudes
{
foreach var of varlist people_cent pop_sov anti_elite populism { 
reg `var' loc_att_rel eu_att_rel /// 
immigration_neg /// 
i.gender i.age_group i.education_tertiary i.country [pweight=weight]
eststo relatt_`var'
estat vif
}

coefplot relatt_populism relatt_pop_sov relatt_people_cent relatt_anti_elite, /// Coefficient plot
keep(loc_att_rel eu_att_rel) xtitle("Populist attitudes [0-4]") coeflabels(,wrap(20) labsize(medium)) ///
legend(label(2 "Populism (overall)") label(4 "Popular sovereignty")  label(6 "People-centrism")  label(8 "Anti-elitism") ///
rows(2) region(lcolor(none) fcolor(none))) ///
xline(0, lpattern(shortdash) lwidth(vthin)) graphregion(fcolor(white) lcolor(white)) scheme(s1mono) /// 
ciopts(lwidth(thin) lcolor(gs3)) msize(medium) mcolor(gs3) mfcolor(none)
graph export Figure_2.png, width(2000) replace

esttab relatt_anti_elite relatt_people_cent relatt_pop_sov relatt_populism /// Regression table
using Table_A2.rtf, replace label nobase nogaps ///
title("Populist attitudes and scalar orientation") ///
b(3) se(3) star(* 0.05 ** 0.01 *** 0.001)  /// 
scalars("N N" "F F-Test" "p p>F" "r2_a Adjusted-R2") sfmt(0 3 3 3)
}

	// 4.2 Interaction effects: scalar orientation and left-right self-placement
{
foreach var of varlist people_cent pop_sov anti_elite populism { /* interaction local scalar orientation x left-right self-placement */
reg `var' c.loc_att_rel##c.left_right eu_att_rel ///
i.gender i.age_group i.education_tertiary i.country [pweight=weight]
eststo lrloc_`var'
estat vif

est restore lrloc_`var' // Interaction plots
margins, dydx(loc_att_rel) at(left_right=(0(1)10)) 
marginsplot, scheme(s1mono) yline(0, lpattern(shortdash)) recastci(rarea) ci1opts(color(%30) alwidth(none)) /// 
plotopts(msymbol(i)) title("") ytitle("Coefficient of" "local scalar orientation") ///
xtitle("Left-right self placement") title(`: variable label `var'') ///
addplot(hist left_right, freq yaxis(2) yscale(alt axis(2)) xlabel(0(1)10) ytitle("Number of respondents", axis(2)) /// 
color(none) lcolor(gs6) lwidth(vthin) lpattern(dash) below) legend(off) saving(DV`var'_intlrloc, replace)
}

graph combine DVpopulism_intlrloc.gph DVpop_sov_intlrloc.gph DVpeople_cent_intlrloc.gph DVanti_elite_intlrloc.gph, ///
scheme(s1mono) graphregion(lcolor(white)) iscale(0.7)
graph export Figure_3.png, width(2000) replace

erase DVpopulism_intlrloc.gph
erase DVpop_sov_intlrloc.gph 
erase DVpeople_cent_intlrloc.gph 
erase DVanti_elite_intlrloc.gph

foreach var of varlist people_cent pop_sov anti_elite populism { /* interaction European scalar orientation x left-right self-placement */
reg `var' loc_att_rel c.eu_att_rel##c.left_right ///
i.gender i.age_group i.education_tertiary i.country  [pweight=weight]
eststo lreu_`var'
estat vif

est restore lreu_`var' // Interaction plots
margins, dydx(eu_att_rel) at(left_right=(0(1)10)) 
marginsplot, scheme(s1mono) yline(0, lpattern(shortdash)) recastci(rarea) ci1opts(color(%30) alwidth(none)) /// 
plotopts(msymbol(i)) title("") ytitle("Coefficient of" "European scalar orientation") ///
xtitle("Left-right self placement") title(`: variable label `var'') ///
addplot(hist left_right, freq yaxis(2) yscale(alt axis(2)) xlabel(0(1)10) ytitle("Number of respondents", axis(2)) /// 
color(none) lcolor(gs6) lwidth(vthin) lpattern(dash) below) legend(off) saving(DV`var'_intlreu, replace)
}

graph combine DVpopulism_intlreu.gph DVpop_sov_intlreu.gph DVpeople_cent_intlreu.gph DVanti_elite_intlreu.gph, ///
scheme(s1mono) graphregion(lcolor(white)) iscale(0.7)
graph export Figure_4.png, width(2000) replace

erase DVpopulism_intlreu.gph
erase DVpop_sov_intlreu.gph 
erase DVpeople_cent_intlreu.gph 
erase DVanti_elite_intlreu.gph


esttab lrloc_anti_elite lrloc_people_cent lrloc_pop_sov lrloc_populism /// Regression table: left-right x scalar orientation
lreu_anti_elite lreu_people_cent lreu_pop_sov lreu_populism ///
using Table_A3.rtf, replace label nobase nogaps ///
title("Populist attitudes: scalar orientation and left-right self-placement") ///
b(3) se(3) star(* 0.05 ** 0.01 *** 0.001)  /// 
scalars("N N" "F F-Test" "p p>F" "r2_a Adjusted-R2") sfmt(0 3 3 3)


}


// 5. Robustness

	// 5.1 Interaction effects: scalar orientation and party identification
{
foreach var of varlist people_cent pop_sov anti_elite populism { // interaction local scalar orientation x party identification
reg `var' c.loc_att_rel##i.party_id eu_att_rel /// 
immigration_neg /// 
i.gender i.age_group i.education_tertiary i.country [pweight=weight] // 
eststo pidloc_`var'
estat vif

est restore pidloc_`var'
margins, at(loc_att_rel=(-10(1)10)) over(party_id) 
marginsplot, by(party_id, label("None" "Other" "Left-wing populist" "Right-wing populist")) /// 
scheme(s1mono) recastci(rarea) ci1opts(color(%30) alwidth(none)) /// 
plotopts(msymbol(i)) ytitle(`: variable label `var'') ///
xtitle("Local scalar orientation") legend(off) /// 
xlabel(-10(5)10, grid glcolor(gs14) glwidth(vthin)) /// 
ylabel(, grid glcolor(gs14) glwidth(vthin)) ///
subtitle(,fcolor(white) lcolor(white)) byopts(title("")) saving(DV`var'_intpidloc, replace)
}

graph combine DVpopulism_intpidloc.gph DVpop_sov_intpidloc.gph DVpeople_cent_intpidloc.gph DVanti_elite_intpidloc.gph, ///
scheme(s1mono) graphregion(lcolor(white)) iscale(0.7)
graph export Figure_A3.png, width(2000) replace

erase DVpopulism_intpidloc.gph 
erase DVpop_sov_intpidloc.gph 
erase DVpeople_cent_intpidloc.gph 
erase DVanti_elite_intpidloc.gph

foreach var of varlist people_cent pop_sov anti_elite populism { // interaction European scalar orientation x party identification
reg `var' loc_att_rel c.eu_att_rel##i.party_id /// 
immigration_neg /// 
i.gender i.age_group i.education_tertiary i.country [pweight=weight] 
eststo pideu_`var'
estat vif

est restore pideu_`var'
margins, at(eu_att_rel=(-10(1)10)) over(party_id) 
marginsplot, by(party_id, label("None" "Other" "Left-wing populist" "Right-wing populist")) /// 
scheme(s1mono) recastci(rarea) ci1opts(color(%30) alwidth(none)) /// 
plotopts(msymbol(i)) ytitle(`: variable label `var'') ///
xtitle("European scalar orientation") legend(off) /// 
xlabel(-10(5)10, grid glcolor(gs14) glwidth(vthin)) /// 
ylabel(, grid glcolor(gs14) glwidth(vthin)) ///
subtitle(,fcolor(white) lcolor(white)) byopts(title("")) saving(DV`var'_intpideu, replace)
}

graph combine DVpopulism_intpideu.gph DVpop_sov_intpideu.gph DVpeople_cent_intpideu.gph DVanti_elite_intpideu.gph, ///
scheme(s1mono) graphregion(lcolor(white)) iscale(0.7)
graph export Figure_A4.png, width(2000) replace

erase DVpopulism_intpideu.gph 
erase DVpop_sov_intpideu.gph 
erase DVpeople_cent_intpideu.gph 
erase DVanti_elite_intpideu.gph

esttab pidloc_anti_elite pidloc_people_cent pidloc_pop_sov pidloc_populism /// Regression table: left-right x scalar orientation
pideu_anti_elite pideu_people_cent pideu_pop_sov pideu_populism ///
using Table_A4.rtf, replace label nobase nogaps ///
title("Populist attitudes: scalar orientation and party identification") ///
b(3) se(3) star(* 0.05 ** 0.01 *** 0.001)  /// 
scalars("N N" "F F-Test" "p p>F" "r2_a Adjusted-R2") sfmt(0 3 3 3)


}

	// 5.2 Robustness: re-estimation under exlusion of one country
{
foreach i of numlist 1/4 { 
reg populism loc_att_rel eu_att_rel ///
immigration_neg ///
i.gender i.age_group i.education_tertiary i.country if country!=`i' [pweight=weight]
eststo jk_not`i'
estat vif
}

coefplot jk_not1 jk_not2 jk_not3 jk_not4, /// Coefficient plots: continuous DV
keep(loc_att_rel eu_att_rel) xtitle("Populism (overall) [0-4]") coeflabels(,wrap(20) labsize(medium)) ///
legend(title("Excluding", size(medium) position(9) margin(medium)) label(2 "Switzerland") label(4 "Germany")  label(6 "France")  label(8 "United Kingdom") ///
rows(2) region(lcolor(none) fcolor(none))) ///
xline(0, lpattern(shortdash) lwidth(vthin)) graphregion(fcolor(white) lcolor(white)) scheme(s1mono) /// 
ciopts(lwidth(thin) lcolor(gs3)) msize(medium) mcolor(gs3) mfcolor(none)
graph export Figure_A2.png, width(2000) replace
}
